@@ -24,13 +24,16 @@ typedef struct
 	char *name;
 }command_t;
 
+extern char *reserved_commands[];
+
 command_t *command_list;
 
-int get_command(FileView *view, int type, char *string);
+int get_command(FileView *view, int type, void *ptr);
 void shellout(char *command, int pause);
 void add_command(char *name, char *action);
 int execute_command(FileView *view, char *action);
 int sort_this(const void *one, const void *two);
 int is_user_command(char *command);
-char * expand_macros(FileView *view, char *command, char *args);
+int command_is_reserved(char *command);
+char * expand_macros(FileView *view, char *command, char *args, int *menu, int *split);
 void remove_command(char *name);
