@@ -33,6 +33,7 @@ enum {
 };
 
 
+void quick_view_file(FileView * view);
 void change_directory(FileView *view, char *directory);
 void load_dir_list(FileView *view, int reload);
 void draw_dir_list(FileView *view, int top, int pos);
@@ -41,5 +42,6 @@ void moveto_list_pos(FileView *view, int pos);
 int find_file_pos_in_list(FileView *view, char *file);
 void get_all_selected_files(FileView *view);
 void free_selected_file_array(FileView *view);
+void erase_current_line_bar(FileView *view);
 
 #endif
