@@ -26,6 +26,7 @@
 
 #include "background.h"
 #include "bookmarks.h"
+#include "color_scheme.h"
 #include "commands.h"
 #include "config.h"
 #include "file_info.h"
@@ -106,7 +107,7 @@ check_if_filelists_have_changed(FileView *view)
 	if(s.st_mtime  != view->dir_mtime)
 		reload_window(view);
 
-	if (curr_stats.number_of_windows != 1)
+	if (curr_stats.number_of_windows != 1 && curr_stats.view != 1)
 	{
 		stat(other_view->curr_dir, &s);
 		if(s.st_mtime != other_view->dir_mtime)
@@ -149,7 +150,6 @@ rename_file(FileView *view)
 	len = strlen(filename);
 	wmove(view->win, view->curr_line, strlen(filename) + 1);
 
-//	wmove(view->win, view->curr_line, 1);
 	curs_set(1);
 
   while(!done)
@@ -291,7 +291,7 @@ remove_filename_filter(FileView *view)
 	view->prev_filter = (char *)realloc(view->prev_filter,
 			strlen(view->filename_filter) +1);
 	snprintf(view->prev_filter, 
-		sizeof(view->prev_filter), "%s", view->filename_filter);
+		sizeof(view->prev_filter), view->filename_filter);
 	view->filename_filter = (char *)realloc(view->filename_filter,
 			strlen("*") +1);
 	snprintf(view->filename_filter, 
@@ -312,13 +312,13 @@ restore_filename_filter(FileView *view)
 	int found;
 	char file[NAME_MAX];
 
-	snprintf(file, sizeof(file), "%s",
+	snprintf(file, sizeof(file), "%s", 
 			view->dir_entry[view->list_pos].name);
 
 	view->filename_filter = (char *)realloc(view->filename_filter,
 			strlen(view->prev_filter) +1);
-	snprintf(view->filename_filter, 
-		sizeof(view->filename_filter), "%s", view->prev_filter);
+	snprintf(view->filename_filter, sizeof(view->filename_filter), 
+			"%s", view->prev_filter);
 	view->invert = view->prev_invert;
 	load_dir_list(view, 0);
 	found = find_file_pos_in_list(view, file); 
@@ -518,7 +518,7 @@ show_dot_files(FileView *view)
 	int found;
 	char file[256];
 
-	snprintf(file, sizeof(file), "%s",
+	snprintf(file, sizeof(file), "%s", 
 			view->dir_entry[view->list_pos].name);
 	view->hide_dot = 0;
 	load_dir_list(view, 1);
@@ -535,6 +535,7 @@ hide_dot_files(FileView *view)
 {
 	int found;
 	char file[NAME_MAX];
+
 	snprintf(file, sizeof(file), "%s",
 			view->dir_entry[view->list_pos].name);
 	view->hide_dot = 1;
@@ -552,6 +553,7 @@ toggle_dot_files(FileView *view)
 {
 	int found;
 	char file[NAME_MAX];
+
 	snprintf(file, sizeof(file), "%s",
 			view->dir_entry[view->list_pos].name);
 	if(view->hide_dot)
@@ -584,9 +586,23 @@ change_window(FileView **view)
 		wnoutrefresh(other_view->title);
 	}
 
+	if (curr_stats.view)
+	{
+
+		wbkgdset(curr_view->title,
+			   	COLOR_PAIR(BORDER_COLOR + curr_view->color_scheme));
+		wbkgdset(curr_view->win,
+			   	COLOR_PAIR(WIN_COLOR + curr_view->color_scheme));
+		change_directory(other_view, other_view->curr_dir);
+		load_dir_list(other_view, 0);
+		change_directory(curr_view, curr_view->curr_dir);
+		load_dir_list(curr_view, 0);
+
+	}
+
 	wattron(curr_view->title, A_BOLD);
 	werase(curr_view->title);
-	wprintw(curr_view->title, "%s", curr_view->curr_dir);
+	wprintw(curr_view->title,  "%s", curr_view->curr_dir);
 	wnoutrefresh(curr_view->title);
 
 	wnoutrefresh(other_view->win);
@@ -603,6 +619,8 @@ change_window(FileView **view)
 	
 	if (curr_stats.number_of_windows == 1)
 		update_all_windows();
+
+
 }
 
 static void
@@ -808,8 +826,28 @@ main_key_press_cb(FileView *view)
 		/* This waits for 1 second then skips if no keypress. */
 		key = wgetch(view->win);
 
+
 		if (key == ERR)
 			continue;
+		else /* Puts the cursor at the start of the line for speakup */
+		{
+			/*
+			int x, y;
+			char buf[256];
+
+			getyx(view->win, y, x);
+			
+			snprintf(buf, sizeof(buf), "x is %d y is %d ", x, y);
+			show_error_msg("cursor curr_win", buf);
+
+			wmove(stdscr, y + 2, 0);
+			wrefresh(stdscr);
+
+			getyx(stdscr, y, x);
+			snprintf(buf, sizeof(buf), "x is %d y is %d ", x, y);
+			show_error_msg("stdscr win", buf);
+			*/
+		}
 
 		/* This point down gets called only when a key is actually pressed */
 
