@@ -29,13 +29,18 @@ enum {
 	GET_VISUAL_COMMAND,
 	START_VISUAL_MODE,
 	MAPPED_COMMAND,
-	MAPPED_SEARCH
+	MAPPED_SEARCH,
+	MENU_SEARCH,
+	MENU_COMMAND
 };
 
 
 void main_key_press_cb(FileView *view);
 void update_all_windows(void);
-
+void show_dot_files(FileView *view);
+void remove_filename_filter(FileView *view);
+void rename_file(FileView *view);
+void switch_views(void);
 #endif
 
 
