@@ -26,9 +26,16 @@ void show_commands_menu(FileView *view);
 void show_history_menu(FileView *view);
 void show_vifm_menu(FileView *view);
 void show_filetypes_menu(FileView *view);
+void show_jobs_menu(FileView *view);
+void show_locate_menu(FileView *view, char *args);
+void show_apropos_menu(FileView *view, char *args);
+void show_user_menu(FileView *view, char *command); 
+void show_register_menu(FileView *view);
 void reset_popup_menu(void);
 void setup_menu(FileView *view);
 void show_error_msg(char * title, char *message);
+int search_menu_list(FileView *view, char * command, void * ptr);
+int execute_menu_command(FileView *view, char * command, void * ptr);
 
 
 #endif
