@@ -26,13 +26,22 @@ typedef struct
 	char **yanked_files;
 	int need_redraw;
 	volatile int freeze;
-	volatile int popup_showing;
 	volatile int getting_input;
+	volatile int menu;
+	int redraw_menu;
 	int is_updir;
 	int last_char;
 	char updir_file[NAME_MAX];
 	int is_console;
 	time_t config_file_mtime;
+	int search;
+	int save_msg;
+	int use_register;
+	int curr_register;
+	int register_saved;
+	int number_of_windows;
+	int view;
+	int show_full;
 }Status;
 
 extern Status curr_stats;
